@@ -22,7 +22,7 @@ from ..models import (
     EveUnit,
 )
 from ..utils import NoSocketsTestCase
-from .testdata.esi import EsiClientStub
+from .testdata.esi import BravadoOperationStub, EsiClientStub
 from .testdata.factories import create_eve_entity
 
 unittest.util._MAX_LENGTH = 1000
@@ -793,7 +793,7 @@ class TestEveEntity(NoSocketsTestCase):
 
 @patch(MANAGERS_PATH + ".esi")
 class TestEveEntityEsi(NoSocketsTestCase):
-    def test_can_create_new_from_esi(self, mock_esi):
+    def test_can_create_new_from_esi_with_id(self, mock_esi):
         # given
         mock_esi.client = EsiClientStub()
         # when
@@ -804,7 +804,7 @@ class TestEveEntityEsi(NoSocketsTestCase):
         self.assertEqual(obj.name, "Bruce Wayne")
         self.assertEqual(obj.category, EveEntity.CATEGORY_CHARACTER)
 
-    def test_get_or_create_esi_1(self, mock_esi):
+    def test_get_or_create_esi_with_id_1(self, mock_esi):
         """when object already exists, then just return it"""
         # given
         mock_esi.client = EsiClientStub()
@@ -815,7 +815,7 @@ class TestEveEntityEsi(NoSocketsTestCase):
         self.assertFalse(created)
         self.assertEqual(obj_1, obj_2)
 
-    def test_get_or_create_esi_2(self, mock_esi):
+    def test_get_or_create_esi_with_id_2(self, mock_esi):
         """when object doesn't exist, then fetch it from ESi"""
         # given
         mock_esi.client = EsiClientStub()
@@ -825,7 +825,7 @@ class TestEveEntityEsi(NoSocketsTestCase):
         self.assertTrue(created)
         self.assertEqual(obj.name, "Bruce Wayne")
 
-    def test_get_or_create_esi_3(self, mock_esi):
+    def test_get_or_create_esi_with_id_3(self, mock_esi):
         """when ID is invalid, then return an empty object"""
         # given
         mock_esi.client = EsiClientStub()
@@ -835,7 +835,7 @@ class TestEveEntityEsi(NoSocketsTestCase):
         self.assertIsNone(obj)
         self.assertFalse(created)
 
-    def test_get_or_create_esi_4(self, mock_esi):
+    def test_get_or_create_esi_with_id_4(self, mock_esi):
         """when object already exists and has not yet been resolved, fetch it from ESI"""
         # given
         mock_esi.client = EsiClientStub()
@@ -905,6 +905,41 @@ class TestEveEntityEsi(NoSocketsTestCase):
         self.assertEqual(EveEntity.objects.resolve_name(999), "")
         self.assertEqual(EveEntity.objects.resolve_name(None), "")
 
+    def test_can_fetch_entity_by_name_from_esi(self, mock_esi):
+        # given
+        mock_esi.client = EsiClientStub()
+        # when
+        result = EveEntity.objects.fetch_by_names_esi(["Bruce Wayne"])
+        # then
+        self.assertListEqual(list(result), list(EveEntity.objects.filter(id=1001)))
+
+    def test_can_fetch_entities_by_name_from_esi(self, mock_esi):
+        # given
+        mock_esi.client = EsiClientStub()
+        # when
+        result = EveEntity.objects.fetch_by_names_esi(["Bruce Wayne", "Caldari State"])
+        # then
+        self.assertListEqual(
+            list(result), list(EveEntity.objects.filter(id__in=[500001, 1001]))
+        )
+
+    def test_can_fetch_entities_by_name_from_esi_huge(self, mock_esi):
+        # given
+        def my_endpoint(names):
+            characters = [
+                {"id": int(name.split("_")[1]), "name": name} for name in names
+            ]
+            data = {"characters": characters}
+            return BravadoOperationStub(data)
+
+        mock_esi.client.Universe.post_universe_ids.side_effect = my_endpoint
+        names = [f"dummy_{num + 1001}" for num in range(600)]
+        # when
+        result = EveEntity.objects.fetch_by_names_esi(names)
+        # then
+        self.assertEqual(mock_esi.client.Universe.post_universe_ids.call_count, 2)
+        self.assertEqual(len(result), 600)
+
     def test_can_bulk_resolve_name(self, mock_esi):
         # given
         mock_esi.client = EsiClientStub()
